Learn R Programming

NPCirc (version 3.2.1)

inclusion.trails: Porphyroblast inclusion trails dataset

Description

This dataset corresponds to two-dimensional axial orientations of porphyroblast inclusion trails, obtained from oriented rock samples of the Cenozoic Betic-Rif orogen of southern Spain and northern Morocco. About 60% of this data was published by Aerden et al (2022) and Ruiz-Fuentes and Aerden (2023) and the rest collected subsequently by the same authors. The whole dataset was analyzed in Alonso-Pena et al (2026).

Usage

data(inclusion.trails)

Arguments

Format

A data frame with 2827 observations on the following 6 variables:

Tectonic.UNIT

Factor indicating the tectonic unit to which the observation belongs.

Area

Factor indicating the broader geographical area.

Subarea

Factor specifying a subdivision within the area.

Strike.of.Si

Numeric variable giving the axial orientation (strike) of the inclusion trails, measured in degrees. Directions are recorded clockwise from North (0 degrees).

Mineral

Factor indicating the mineral type of the porphyroblast.

Type

Factor indicating the method used to obtain the strike measurement.

Details

The dataset contains measurements of porphyroblast inclusion-trail orientations collected in a structural geology context. The key variable is Strike.of.Si, which represents axial directional data expressed in degrees.

Because the data are axial, orientations differing by 180 degrees represent the same structural direction. All angles are measured clockwise, with 0 degrees corresponding to North.

Examples

Run this code
data(inclusion.trails)
directions <- circular(inclusion.trails$Strike.of.Si,units="degrees",
                        template="geographics",modulo="pi")

Run the code above in your browser using DataLab